package com.huiju.estateagents.sample.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.sample.entity.TaH5Demand;
import com.huiju.estateagents.sample.service.ITaH5DemandService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;


/**
 * <p>
    * 需求单表  前端控制器
    * </p>
 *
 * @author fxf
 * @since 2020-03-18
 */
@RestController
@RequestMapping("/api")
public class TaH5DemandController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaH5DemandController.class);

    @Autowired
    public ITaH5DemandService iTaH5DemandService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taH5Demand",method= RequestMethod.GET)
    public ResponseBean taH5DemandList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                       HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaH5Demand> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaH5Demand> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("org_id", getOrgId(request));
            queryWrapper.orderByDesc("create_date");

            IPage<TaH5Demand> result = iTaH5DemandService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5DemandList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taH5Demand 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taH5Demand",method= RequestMethod.POST)
    public ResponseBean taH5DemandAdd(@RequestBody TaH5Demand taH5Demand){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaH5DemandService.save(taH5Demand)){
                responseBean.addSuccess(taH5Demand);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5DemandAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taH5Demand/{id}", method= RequestMethod.DELETE)
    public ResponseBean taH5DemandDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaH5DemandService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5DemandDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taH5Demand 实体对象
     * @return
     */
    @RequestMapping(value="/taH5Demand/{id}",method= RequestMethod.PUT)
    public ResponseBean taH5DemandUpdate(@PathVariable Integer id,
                                        @RequestBody TaH5Demand taH5Demand){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaH5DemandService.updateById(taH5Demand)){
                responseBean.addSuccess(taH5Demand);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5DemandUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taH5Demand/{id}",method= RequestMethod.GET)
    public ResponseBean taH5DemandGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaH5DemandService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5DemandDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
